==> open-xchange-server_6.12.0.0.orig.tar.gz: open-xchange-server-6.12.0.0/src/com/openexchange/ajp13/monitoring/AJPv13Monitors.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.ajp13.monitoring;

/**
 * {@link AJPv13Monitors} - Provides access to AJP's monitor variables.
 * 
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class AJPv13Monitors {

    /**
     * Initializes a new {@link AJPv13Monitors}.
     */
    private AJPv13Monitors() {
        super();
    }

    /**
     * The singleton instance of {@link AJPv13ServerThreadsMonitor}.
     */
    public static final AJPv13ServerThreadsMonitor AJP_MONITOR_SERVER_THREADS = new AJPv13ServerThreadsMonitor();

    /**
     * The instance of {@link AJPv13ListenerMonitorMBean}.
     */
    private static volatile AJPv13ListenerMonitorMBean listenerMonitor;

    /**
     * Sets the listener monitor instance.
     * 
     * @param listenerMonitor
     */
    public static void setListenerMonitor(final AJPv13ListenerMonitorMBean listenerMonitor) {
        AJPv13Monitors.listenerMonitor = listenerMonitor;
    }

    /**
     * Releases the listener monitor instance.
     */
    public static void releaseListenerMonitor() {
        AJPv13Monitors.listenerMonitor = null;
    }

    /**
     * Gets the listener monitor instance.
     * 
     * @return The listener monitor instance.
     */
    public static AJPv13ListenerMonitorMBean getListenerMonitor() {
        return listenerMonitor;
    }

}

==> open-xchange-server_6.14.0.0.orig.tar.gz: open-xchange-server-6.14.0.0/src/com/openexchange/ajp13/monitoring/AJPv13Monitors.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.ajp13.monitoring;

/**
 * {@link AJPv13Monitors} - Provides access to AJP's monitor variables.
 * 
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class AJPv13Monitors {

    /**
     * Initializes a new {@link AJPv13Monitors}.
     */
    private AJPv13Monitors() {
        super();
    }

    /**
     * The singleton instance of {@link AJPv13ServerThreadsMonitor}.
     */
    public static final AJPv13ServerThreadsMonitor AJP_MONITOR_SERVER_THREADS = new AJPv13ServerThreadsMonitor();

    /**
     * The instance of {@link AJPv13TaskMonitorMBean}.
     */
    private static volatile AJPv13TaskMonitorMBean listenerMonitor;

    /**
     * Sets the listener monitor instance.
     * 
     * @param listenerMonitor
     */
    public static void setListenerMonitor(final AJPv13TaskMonitorMBean listenerMonitor) {
        AJPv13Monitors.listenerMonitor = listenerMonitor;
    }

    /**
     * Releases the listener monitor instance.
     */
    public static void releaseListenerMonitor() {
        AJPv13Monitors.listenerMonitor = null;
    }

    /**
     * Gets the listener monitor instance.
     * 
     * @return The listener monitor instance.
     */
    public static AJPv13TaskMonitorMBean getListenerMonitor() {
        return listenerMonitor;
    }

}
